@@ -1,25 +1,24 @@
-from datetime import datetime, timedelta, timezone
-from typing import Any, Callable, Literal
 import json
 import logging
 import os
 import time
 import traceback
+from datetime import datetime, timedelta, timezone
+from typing import Any, Callable, Literal
+from urllib.parse import quote
 
 from flask import Flask, Response, abort, g, make_response, redirect, request, send_from_directory
 from flask_jwt_extended import JWTManager, create_access_token, get_jwt, get_jwt_identity, set_access_cookies, verify_jwt_in_request  # type: ignore
-from urllib.parse import quote
 from sqlalchemy.orm import Session
 
+import bafser_config
 
 from . import db_session
-from .authentication import get_user_id_by_jwt_identity
 from .alembic import alembic_upgrade
+from .authentication import get_user_id_by_jwt_identity
 from .doc_api import init_api_docs
 from .logger import get_logger_requests, setLogging
 from .utils import get_json, get_secret_key, get_secret_key_rnd, randstr, register_blueprints, response_msg
-import bafser_config
-
 
 _config: "AppConfig | None" = None
 
@@ -142,8 +141,9 @@ def create_app(import_name: str, config: AppConfig):
                 change_admin_default_pwd(db_sess)
 
     def change_admin_default_pwd(db_sess: Session):
-        from . import UserBase
-        admin = UserBase.get_by_login(db_sess, "admin", includeDeleted=True)
+        from .data.user import get_user_table
+        User = get_user_table()
+        admin = User.get_by_login(db_sess, "admin", includeDeleted=True)
         if admin is not None and admin.check_password("admin"):
             admin.set_password(randstr(16))
             db_sess.commit()
@@ -151,6 +151,8 @@ def create_app(import_name: str, config: AppConfig):
 
     @app.before_request
     def before_request():  # type: ignore
+        if bafser_config.sql_echo:
+            print(request.path)
         g.json = get_json(request)
         g.req_id = randstr(4)
         try:
@@ -277,3 +279,8 @@ def create_app(import_name: str, config: AppConfig):
 def update_message_to_frontend(msg: str):
     assert _config
     _config.MESSAGE_TO_FRONTEND = msg
+
+
+def get_app_config():
+    assert _config
+    return _config
