@@ -12,7 +12,7 @@ class Permission(SqlAlchemyBase):
     roleId: Mapped[int] = mapped_column(ForeignKey(f"{TablesBase.Role}.id"), primary_key=True)
     operationId: Mapped[str] = mapped_column(String(32), ForeignKey("Operation.id"), primary_key=True)
 
-    operation: Mapped["Operation"] = relationship(init=False)
+    operation: Mapped[Operation] = relationship(init=False)
 
     def __repr__(self):
         return f"<Permission> role: {self.roleId} oper: {self.operationId}"
