@@ -1,4 +1,3 @@
-from typing import get_type_hints
 from typing import Any, Mapping, TypeVar, overload
 
 T = TypeVar("T")
@@ -8,6 +7,8 @@ T3 = TypeVar("T3")
 T4 = TypeVar("T4")
 T5 = TypeVar("T5")
 T6 = TypeVar("T6")
+T7 = TypeVar("T7")
+T8 = TypeVar("T8")
 
 field_desc = tuple[str, type[T]] | tuple[str, type[T], T]
 # field_desc: (field_name, field_type) | (field_name, field_type, default_value)
@@ -28,10 +29,15 @@ def get_json_values(d: Mapping[str, Any], f1: field_desc[T1], f2: field_desc[T2]
 @overload
 def get_json_values(d: Mapping[str, Any], f1: field_desc[T1], f2: field_desc[T2], f3: field_desc[T3], f4: field_desc[T4], f5: field_desc[T5], f6: field_desc[T6]) -> tuple[tuple[T1, T2, T3, T4, T5, T6], error]: ...  # noqa: E704, E501
 @overload
+def get_json_values(d: Mapping[str, Any], f1: field_desc[T1], f2: field_desc[T2], f3: field_desc[T3], f4: field_desc[T4], f5: field_desc[T5], f6: field_desc[T6], f7: field_desc[T7]) -> tuple[tuple[T1, T2, T3, T4, T5, T6, T7], error]: ...  # noqa: E704, E501
+@overload
+def get_json_values(d: Mapping[str, Any], f1: field_desc[T1], f2: field_desc[T2], f3: field_desc[T3], f4: field_desc[T4], f5: field_desc[T5], f6: field_desc[T6], f7: field_desc[T7], f8: field_desc[T8]) -> tuple[tuple[T1, T2, T3, T4, T5, T6, T7, T8], error]: ...  # noqa: E704, E501
+@overload
 def get_json_values(d: Mapping[str, Any], *field_names: field_desc[Any]) -> tuple[values, error]: ...  # noqa: E704
 
 
 def get_json_values(d: Mapping[str, Any], *field_names: field_desc[Any], **kwargs: Any) -> tuple[values, error]:
+    from ..jsonobj import validate_type
     if kwargs != {}:
         raise Exception("dont support kwargs")
     r: list[Any] = []
@@ -46,10 +52,10 @@ def get_json_values(d: Mapping[str, Any], *field_names: field_desc[Any], **kwarg
 
         if field_name in d:
             value = d[field_name]
-            _, err = validate_type(value, field_type)
+            value, err = validate_type(value, field_type)
             if err is not None:
                 rv = None if len(field_names) == 1 else list(map(lambda _: None, field_names))
-                return rv, f"{field_name} {err}"
+                return rv, field_name + err
             r.append(value)
         elif have_default:
             r.append(default_value)
@@ -61,26 +67,12 @@ def get_json_values(d: Mapping[str, Any], *field_names: field_desc[Any], **kwarg
     return r, None
 
 
-type SimpleType = Mapping[str, SimpleType] | int | float | bool | str
-TC = TypeVar("TC", bound=SimpleType)
-
-
-def validate_type(obj: Any, otype: type[TC]) -> tuple[TC, None] | tuple[None, str]:
-    if otype in (int, float, bool, str):
-        if isinstance(obj, otype):
-            return obj, None
-        else:
-            return None, f"is not {otype}"
-    if not isinstance(obj, dict):
-        return None, f"is not {otype}"
-
-    type_hints = get_type_hints(otype)
-    for k, t in type_hints.items():
-        if k not in obj:
-            return None, f"field is missing {k}: {t}"
-        v = obj[k]  # type: ignore
-        _, err = validate_type(v, t)
+def get_json_list(l: list[Any], otype: type[T]) -> tuple[list[T], error]:
+    from ..jsonobj import validate_type
+    r: list[T] = []
+    for i, el in enumerate(l):
+        el, err = validate_type(el, otype)
         if err is not None:
-            return None, f"field {k} {err}"
-
-    return obj, None  # type: ignore
+            return [], f"[{i}]{err}"
+        r.append(el)  # type: ignore
+    return r, None
