@@ -2,4 +2,4 @@ from bafser import TablesBase
 
 
 class Tables(TablesBase):
-    pass
+    Apple = "Apple"
